@@ -37,7 +37,9 @@
 extern "C"
 {
 #include "time.h"
-#include <sys/time.h>                                                    
+#if HAVE_SYS_TIME_H
+#include <sys/time.h>
+#endif
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
 #else
@@ -57,6 +59,7 @@ static struct option long_options[] =
     {"version", 0, NULL, VALUE_VERSION},
     {"test", 0, NULL, VALUE_TEST},
     {"return-value", 0, NULL, VALUE_RETURN},
+    {"skip-ssl-verify", 0, NULL, VALUE_SKIP_SSL_VERIFY},
     {0, 0, 0, 0}
   };
 
@@ -76,9 +79,6 @@ string int_to_string          (int);
 int main (int argc, char* argv[])
 {
   Feedback* logger = Feedback :: Instance ();
-  time_t now;
-  struct timeval tv;
-  struct timezone tz;
   string options_set;
   int    return_val = 0;
 
@@ -151,23 +151,10 @@ int main (int argc, char* argv[])
 	Preferences :: Instance ().accounts ()->begin ();
       while (cur_account != Preferences :: Instance ().accounts ()->end ())
 	{
-	  gettimeofday (&tv, &tz);
-	  now = tv.tv_sec;
-	  
-	  // Some versions of ctime () terminate with "\n\0", some don't.
-	  string today_ = ctime (&now);
-	  if (today_[today_.length () - 1] == '\n')
-	    {
-	      char* today = (char*)malloc (sizeof (char) * today_.length ());
-	      snprintf (today, today_.length (), "%s", ctime (&now));
-	      today_ = today;
-	      free (today);
-	    }
 	  logger->print_msg ((string)PACKAGE_VERSION
 			    + " querying "
 			    + cur_account->usr () + "@"
-			    + cur_account->server () + " on "
-			    + today_ + ".",
+			    + cur_account->server () + ".",
 			    3);
 	  
 	  if (cur_account->check () != 0)
@@ -220,7 +207,7 @@ void get_opts (int argc, char* argv[])
   int option = 0;
   int option_index = 0;
 
-  while ((option = getopt_long (argc, argv, "hL:M:Vv:tir",
+  while ((option = getopt_long (argc, argv, "hL:M:Vv:tirs",
 				long_options, &option_index)) != -1)
     {
       switch (option)
@@ -246,6 +233,8 @@ void get_opts (int argc, char* argv[])
 	  cout << "Specify rcfile location" << endl;
 	  cout << "  -r, --return-value         ";
 	  cout << "Enable additional return values" << endl;
+	  cout << "  -s, --skip-ssl-verify      ";
+	  cout << "Skip verification of SSL certificates (Do not use unless you know better!)" << endl;
 	  cout << "  -t, --test                 ";
 	  cout << "Simulate deletes" << endl;
 	  cout << "  -i, --ignore-time-stamps   ";
@@ -291,6 +280,10 @@ void get_opts (int argc, char* argv[])
 	case VALUE_RETURN:
 	  Preferences :: Instance ().set_return_status (true);
 	  break;
+	case 's':
+	case VALUE_SKIP_SSL_VERIFY:
+	  Preferences :: Instance ().set_return_status (true);
+	  break;	  
 	case 'M':
 	case VALUE_MAILFILTERRC:
 	  Preferences :: Instance ().set_rc_file (optarg);
