@@ -1,5 +1,5 @@
 // socket.cc - source file for the mailfilter program
-// Copyright (c) 2003 - 2009  Andreas Bauer <baueran@gmail.com>
+// Copyright (c) 2003 - 2022  Andreas Bauer <baueran@gmail.com>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -38,7 +38,9 @@ extern "C"
 
 extern "C"
 {
+#if HAVE_SYS_TIME_H
 #include <sys/time.h>
+#endif
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <setjmp.h>
@@ -55,6 +57,7 @@ extern "C"
 #include "feedback.hh"
 #include "socket.hh"
 #include "protocol.hh"
+#include "preferences.hh"
 
 using namespace std;
 
@@ -66,6 +69,37 @@ static sigjmp_buf curr_env;
   BIO*        sbio;
   SSL_METHOD* ssl_meth;
   SSL_CTX*    ssl_ctx;
+
+  int Socket :: verify_callback (int preverify_ok, X509_STORE_CTX* ctx)
+  {
+    Feedback* logger = Feedback :: Instance ();
+    // X509* err_cert = X509_STORE_CTX_get_current_cert(ctx); // TODO: use me!
+    int err = X509_STORE_CTX_get_error(ctx);
+    // int depth = X509_STORE_CTX_get_error_depth(ctx); // TODO: use me!
+    
+    if (!preverify_ok)
+      {
+	std::string err_msg("SSL connection could not be established: ");
+	
+	logger->print_err(err_msg += X509_verify_cert_error_string(err));
+	
+	if (Preferences :: Instance().skip_ssl_verify())
+	  {
+	    logger->print_msg("Debugging: SSL certificate verification failed, but continuing anyway.", 6);
+	    return 1; // We pretend, SSL certification was successful as user wanted to skip it
+	  }
+	else
+	  {
+	    logger->print_msg("Debugging: SSL certificate verification failed.", 6);
+	    return 0; // Verification not successful
+	  }
+      }
+    else
+      {
+	logger->print_msg("Debugging: SSL certificate verification successful.", 6);
+	return 1; // Verification successful
+      }
+  }
 #endif
 
 Socket :: Socket (void)
@@ -122,6 +156,8 @@ int Socket :: c_open (const char* host_name,
 	  
 	  ssl_meth = (SSL_METHOD*)(SSLv23_client_method ());
 	  ssl_ctx  = (SSL_CTX*)(SSL_CTX_new (ssl_meth));
+	  SSL_CTX_set_default_verify_paths(ssl_ctx);
+	  SSL_CTX_set_verify(ssl_ctx, SSL_VERIFY_PEER, verify_callback);
 	}
       else
 	logger->print_msg ("Debugging: Client-server communication is not encrypted.", 6);
